@@ -103,7 +103,11 @@ class PandapowerGrid:
                 if self.lf_converged:
                     data[output] = element[output]
                 else:
-                    data[output] = 0  # Return nan?
+                    if etype == "switch":
+                        # Switches don't have numerical outputs
+                        data[output] = element[output]
+                    else:
+                        data[output] = 0  # Return nan?
 
             self.cache[eid] = data
 
